@@ -1,3 +1,4 @@
+#' @rdname decode
 setGeneric("decode", function(.Object, ...) standardGeneric("decode"))
 
 
@@ -7,11 +8,14 @@ setGeneric("decode", function(.Object, ...) standardGeneric("decode"))
 #' 
 #' @param .Object the corpus to decode (character vector)
 #' @param verbose logical
+#' @param sAttribute the s-attribute to decode
+#' @param ... further parameters
 #' @rdname decode
 #' @examples
 #' \dontrun{
 #' PLPRBTTXT <- Corpus$new("PLPRBTTXT")
 #' }
+#' @exportMethod decode
 setMethod("decode", "Corpus", function(.Object, verbose = TRUE){
   if (require(package = "tibble", quietly = TRUE)){
     maxCpos <- CQI$attribute_size(.Object$corpus, "word") - 1
@@ -47,5 +51,20 @@ setMethod("decode", "Corpus", function(.Object, verbose = TRUE){
   } else {
     warning("package 'tibble' required but not available")
   }
+})
 
+#' @rdname decode
+setMethod("decode", "character", function(.Object, sAttribute, verbose = TRUE){
+  cmd <- c(
+    "cwb-s-decode",
+    "-r", Sys.getenv("CORPUS_REGISTRY"), .Object,
+    "-S", sAttribute
+  )
+  if (verbose) message(cmd)
+  raw <- system(paste(cmd, collapse = " ", sep = " "), intern = TRUE)
+  y <- as.data.table(do.call(rbind, strsplit(raw, "\\t")), stringsAsFactors = FALSE)
+  y[[1]] <- as.integer(y[[1]])
+  y[[2]] <- as.integer(y[[2]])
+  colnames(y) <- c("cpos_left", "cpos_right", sAttribute)
+  y
 })
\ No newline at end of file
